package com.seeyon.apps.rss.controller;

import com.seeyon.apps.rss.manager.RssChannelManager;
import com.seeyon.apps.rss.manager.RssFontPageManager;
import com.seeyon.apps.rss.manager.RssManager;
import com.seeyon.apps.rss.po.RssCategory;
import com.seeyon.apps.rss.po.RssCategoryChannel;
import com.seeyon.apps.rss.po.RssChannelInfo;
import com.seeyon.apps.rss.po.RssChannelItems;
import com.seeyon.apps.rss.po.RssSubscribe;
import com.seeyon.apps.rss.vo.ChannelInfoVo;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.authenticate.domain.User;
import com.seeyon.ctp.common.controller.BaseController;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.common.i18n.ResourceUtil;
import com.seeyon.ctp.organization.manager.OrgManager;
import com.seeyon.ctp.util.FlipInfo;
import com.seeyon.ctp.util.annotation.CheckRoleAccess;
import com.seeyon.ctp.util.json.JSONUtil;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.servlet.ModelAndView;

public class RssController extends BaseController {

   private RssChannelManager rssChannelManager;
   private RssManager rssManager;
   private OrgManager orgManager;
   private RssFontPageManager rssFontPageManager;


   public ModelAndView rssBackManage(HttpServletRequest request, HttpServletResponse response) throws Exception {
      List rssTreeMaps = this.rssFontPageManager.getCategoryTreeList((Map)null);
      request.setAttribute("ffrssBackTree", rssTreeMaps);
      return new ModelAndView("apps/rss/rssManage");
   }

   public ModelAndView main(HttpServletRequest request, HttpServletResponse response) throws Exception {
      User user = AppContext.getCurrentUser();
      HashMap params = new HashMap();
      params.put("userId", user.getId());
      List rssTreeMaps = this.rssFontPageManager.getCategoryChannelTreeList(params);
      request.setAttribute("ffrssTree", rssTreeMaps);
      return new ModelAndView("apps/rss/rssMain");
   }

   @CheckRoleAccess(
      resourceCode = {"rss_channel"}
   )
   public ModelAndView index(HttpServletRequest request, HttpServletResponse response) throws Exception {
      boolean rssEnabled = AppContext.hasPlugin("rss");
      return !rssEnabled?new ModelAndView("apps/rss/templete/rssClosed"):this.rssBackManage(request, response);
   }

   public ModelAndView manageMySubscriptions(HttpServletRequest request, HttpServletResponse response) throws Exception {
      User user = AppContext.getCurrentUser();
      Long userId = user.getId();
      List categories = this.rssChannelManager.getAllRssCategories();
      List channels = this.rssChannelManager.getAllRssChannels();
      List mySubscriptionChannel = this.rssManager.getMySubscriptions(userId.longValue());
      ArrayList theCategories = new ArrayList();

      for(int myChannels = 0; myChannels < categories.size(); ++myChannels) {
         int k = 0;
         RssCategory total = (RssCategory)categories.get(myChannels);

         for(int j = 0; j < channels.size(); ++j) {
            RssCategoryChannel channel = (RssCategoryChannel)channels.get(j);
            if(channel.getCategoryId().equals(total.getId())) {
               ++k;
            }
         }

         if(k > 0) {
            theCategories.add(total);
         }
      }

      String var16 = JSONUtil.toJSONString(mySubscriptionChannel);
      request.setAttribute("categories", theCategories);
      request.setAttribute("channels", channels);
      request.setAttribute("myChannels", var16);
      if(channels != null && channels.size() > 0) {
         synchronized(this) {
            long var17 = this.rssManager.getAllSubTotal();
            if(var17 == 0L) {
               this.rssChannelManager.updateAllChannelInfo(false);
            }
         }
      }

      return new ModelAndView("apps/rss/templete/manageMySubscription");
   }

   public ModelAndView listRssItemsByChannelId(HttpServletRequest request, HttpServletResponse response) throws Exception {
      User user = AppContext.getCurrentUser();
      long userId = user.getId().longValue();
      String userType = this.orgManager.getMemberById(Long.valueOf(userId)).getEntityType();
      long channelId = this.getLongParameter(request, "channelId", 0L);
      if(channelId != 0L) {
         RssCategoryChannel categoryChannel = this.rssChannelManager.getChannel(channelId);
         if(categoryChannel == null) {
            throw new BusinessException(ResourceUtil.getString("rss.channel.alter.deleted"));
         }

         RssSubscribe subscribe = this.rssManager.getSubscribeById(userType, userId, channelId);
         RssChannelInfo rssChannelInfo = this.rssChannelManager.getRssChannelByCategoryChannelId(channelId);
         List channelItems = this.rssManager.getSubscribeInfo(channelId);
         List itemIds = this.rssManager.getReadedItemStatusIds(subscribe.getId().longValue(), userId);
         ArrayList channelInfos = new ArrayList();
         int size = channelItems.size();

         for(int channels = 0; channels < size; ++channels) {
            RssChannelItems myChannels = (RssChannelItems)channelItems.get(channels);
            ChannelInfoVo vo = new ChannelInfoVo(myChannels, System.currentTimeMillis());
            if(itemIds.contains(myChannels.getId())) {
               vo.setIsReaded(true);
            }

            channelInfos.add(vo);
         }

         ArrayList var19 = new ArrayList();
         var19.add(categoryChannel);
         String var20 = JSONUtil.toJSONString(var19);
         request.setAttribute("count", Integer.valueOf(size));
         request.setAttribute("categoryChannel", categoryChannel);
         request.setAttribute("channelInfo", rssChannelInfo);
         request.setAttribute("channelInfos", channelInfos);
         request.setAttribute("myChannels", var20.toString());
      }

      return new ModelAndView("apps/rss/templete/channelItems");
   }

   public ModelAndView listRssItems(HttpServletRequest request, HttpServletResponse response) throws Exception {
      User user = AppContext.getCurrentUser();
      Long userId = user.getId();
      List items = this.buildFlipInfo(request, userId.longValue());
      ArrayList channelInfos = new ArrayList();
      List itemIds = this.rssManager.getReadedItems(userId.longValue());
      long currtTime = System.currentTimeMillis();

      ChannelInfoVo vo;
      for(Iterator var10 = items.iterator(); var10.hasNext(); channelInfos.add(vo)) {
         RssChannelItems rssChannelItem = (RssChannelItems)var10.next();
         vo = new ChannelInfoVo(rssChannelItem, currtTime);
         if(itemIds.contains(rssChannelItem.getId())) {
            vo.setIsReaded(true);
         }
      }

      request.setAttribute("channelInfos", channelInfos);
      return new ModelAndView("apps/rss/templete/allItemStatus");
   }

   public ModelAndView rssCategoryEdit(HttpServletRequest request, HttpServletResponse response) throws Exception {
      return new ModelAndView("apps/rss/rssCategoryEdit");
   }

   private List buildFlipInfo(HttpServletRequest request, long userId) {
      int pageNo = this.getIntParameter(request, "pageNo", 1);
      byte pageSize = 20;
      FlipInfo flipInfo = new FlipInfo();
      flipInfo.setSize(pageSize);
      flipInfo.setPage(pageNo);
      List items = this.rssManager.getMyRecentlyItems(flipInfo, userId);
      int count = flipInfo.getTotal();
      int pageCount = count / pageSize;
      if(count % pageSize != 0) {
         ++pageCount;
      }

      if(pageCount > 1) {
         StringBuilder sb = new StringBuilder();
         int k = 10;
         if(pageCount <= 10) {
            k = pageCount;
         }

         for(int i = 1; i <= k; ++i) {
            int m = i;
            if(pageCount > 10 && pageNo >= 8) {
               int j = pageNo - 7;
               if(j + 10 > pageCount) {
                  j = pageCount - 10 + 1;
               }

               m = j + i;
            }

            if(m > pageCount) {
               break;
            }

            if(m != pageNo) {
               sb.append("&nbsp;<a href=\"###\" onclick=\"goPage(\'" + m + "\');\">" + m + "</a>");
            } else {
               sb.append("&nbsp;" + m);
            }
         }

         request.setAttribute("pageHtml", sb.toString());
      }

      request.setAttribute("count", Integer.valueOf(count));
      request.setAttribute("pageCount", Integer.valueOf(pageCount));
      request.setAttribute("pageNo", Integer.valueOf(pageNo));
      return items;
   }

   private long getLongParameter(HttpServletRequest request, String paramName, long param) {
      String id = request.getParameter(paramName);
      if(id != null && !"".equals(id.trim())) {
         param = Long.parseLong(id);
      }

      return param;
   }

   private int getIntParameter(HttpServletRequest request, String paramName, int param) {
      String id = request.getParameter(paramName);
      if(id != null && !"".equals(id.trim())) {
         param = Integer.parseInt(id);
      }

      return param;
   }

   public void setRssChannelManager(RssChannelManager rssChannelManager) {
      this.rssChannelManager = rssChannelManager;
   }

   public void setRssManager(RssManager rssManager) {
      this.rssManager = rssManager;
   }

   public void setOrgManager(OrgManager orgManager) {
      this.orgManager = orgManager;
   }

   public void setRssFontPageManager(RssFontPageManager rssFontPageManager) {
      this.rssFontPageManager = rssFontPageManager;
   }
}
